""" Implementation of WaterFrame.to_pkl(path) """
import pickle


def to_pkl(self, path_pkl):
    """
    Save the WaterFrame into a pickle file.

    Parameters
    ----------
        path_pkl: str
            Location of the pickle file.

    Returns
    -------
        True: bool
            Allways returns true, otherwise it raises an error.
    """
    

    pickle.dump(self.__dict__, open(path_pkl, "wb"))
    return True



""" Implementation of WaterFrame.max(parameter_max) """


def max(self, parameter_max):
    """
    It returns the maximum value of a parameter and the value's indexes.

    Parameters
    ----------
        parameter_max: str
            Name of the parameter.

    Returns
    -------
        max_dict: dict
            Dictionary with the following format:
            {
                '<name of index 1>': <value of index 1>,
                '<name of index n>': <value of index n>,
                'name of parameter': < maximum value of parameter>
            }
    """

    df = self.data[parameter_max]
    df = df.reset_index()

    max_dict = df.loc[df[parameter_max] == df[parameter_max].max()].to_dict('record')[0]

    return max_dict
